|PEGG| PEGG: Prime Editing Guide Generator 
============================================

.. |PEGG| image:: src/docs/PEGG_3.png
   :width: 200px
   :height: 200px

`Full Documentation is available here (pegg.readthedocs.io) <https://pegg.readthedocs.io/en/latest/>`_

PEGG is a python module that designs prime editing guide RNAs (pegRNAs) for use in precision genome editing.
Unlike the existing, web-based programs for pegRNA design, PEGG is suitable for designing thousands of pegRNAs at once, giving users the ability to design entire libraries of pegRNAs.

PEGG's main functions are:

(1) Generating pegRNAs based on a list of input mutations

(2) Ranking and filtering these pegRNAs based on their properties

(3) Automated oligo generation

(4) Automated pegRNA library design with included silent substitution control pegRNAs

(5) Visualization Tools for individual pegRNA design and library design

Upcoming versions of PEGG will also include the ability to map mutations from the human to the mouse genome.
